Module spec

Module spec 

Window function spec and frame types serialized over the SPSC bridge.

Structs

WindowFrame
Window frame: defines which rows within the partition are visible to the function.
WindowFuncSpec
A window function specification.

Enums

FrameBound
Window frame boundary.