array_header

Function array_header 

pub fn array_header(buf: &[u8], offset: usize) -> Option<(usize, usize)>
Return the number of elements and the offset of the first element, for the array starting at offset. Returns None if not an array.